==> vaycore-0.2.1.tar.gz: lib/dio/default_adapter.dart <==
import 'dart:io';

import 'package:dio/dio.dart';
import 'package:vaycore/http.dart';
import 'package:vaycore/vaycore.dart';

///
/// @author vay
/// @email hxhvay@126.com
/// @date 2020-05-09
///

class DefaultAdapter extends BaseNetAdapter {
  String _baseApiUrl;
  Dio _dio;
  Map<String, dynamic> _defaultHeaders;
  List<dynamic> _interceptors;

  DefaultAdapter({String baseApiUrl}) {
    _defaultHeaders = {HttpHeaders.userAgentHeader: "dio-3.0.9"};
    this._baseApiUrl = baseApiUrl ?? "";
  }

  void _initInterceptors() {
    if (_interceptors == null) {
      _interceptors = List();
    } else {
      _interceptors.clear();
    }
    if (core.options.isDebug) {
      _interceptors.add(LogInterceptor(
          request: core.options.logOptions.request,
          requestHeader: core.options.logOptions.requestHeader,
          requestBody: core.options.logOptions.requestBody,
          responseHeader: core.options.logOptions.responseHeader,
          responseBody: core.options.logOptions.responseBody,
          error: core.options.logOptions.error,
          logPrint: core.options.logOptions.logPrint));
    }
  }

  @override
  Future<HttpResult<T>> request<T>(RequestParams params) async {
    assert(params != null);
    // 先初始化dio对象
    _initDio(params);

    if (params.transformer != null) {
      _dio.transformer = params.transformer;
    }

    // 防止重复添加
    _initInterceptors();
    if (params.interceptors != null && params.interceptors.isNotEmpty) {
      params.interceptors.forEach((element) {
        _dio.interceptors.add(element);
      });
    }

    String url = wrapUrlByParams(params.method, params.url, params.data);
    try {
      Response response = await _doRequest(url, params);
      T data = params.parser<T>(response.data);
      return HttpResult<T>(ResultStatus.success, data: data);
    } catch (e) {
      return HttpResult<T>(ResultStatus.failed, error: e);
    }
  }

  Future<Response> _doRequest(String url, RequestParams params) async {
    Future<Response> response;
    switch (params.method) {
      case HttpMethod.POST:
        response = _dio.post(url, data: params.data);
        break;
      case HttpMethod.PUT:
        response = _dio.put(url, data: params.data);
        break;
      case HttpMethod.DELETE:
        response = _dio.delete(url, data: params.data);
        break;
      case HttpMethod.HEAD:
        response = _dio.head(url);
        break;
      case HttpMethod.PATCH:
        response = _dio.patch(url);
        break;
      case HttpMethod.GET:
      default:
        response = _dio.get(url);
        break;
    }
    return response;
  }

  _initDio(RequestParams params) {
    if (_dio != null) {
      return;
    }
    _dio = Dio(BaseOptions(
        baseUrl: _baseApiUrl,
        connectTimeout: params.timeout,
        receiveTimeout: params.timeout,
        headers: params.header ?? _defaultHeaders,
        contentType: params.contentType ?? Headers.jsonContentType,
        responseType: params.responseType ?? ResponseType.json,
        validateStatus: (status) {
          return status >= 200 && status < 300 || status == 304;
        }));
  }
}

==> vaycore-0.5.1.tar.gz: lib/dio/default_adapter.dart <==
import 'dart:io';

import 'package:dio/dio.dart';
import 'package:vaycore/http.dart';
import 'package:vaycore/vaycore.dart';

///
/// @author vay
/// @email hxhvay@126.com
/// @date 2020-05-09
///

class DefaultAdapter extends BaseNetAdapter {
  String _baseApiUrl;
  Dio _dio;
  Map<String, dynamic> _defaultHeaders;

  DefaultAdapter({String baseApiUrl}) {
    _defaultHeaders = {HttpHeaders.userAgentHeader: "dio-3.0.9"};
    this._baseApiUrl = baseApiUrl ?? "";
  }

  void _initInterceptors() {
    if (_dio.interceptors == null) {
      return;
    }
    _dio.interceptors.clear();
    if (core.options.isDebug) {
      _dio.interceptors.add(LogInterceptor(
          request: core.options.httpLog.request,
          requestHeader: core.options.httpLog.requestHeader,
          requestBody: core.options.httpLog.requestBody,
          responseHeader: core.options.httpLog.responseHeader,
          responseBody: core.options.httpLog.responseBody,
          error: core.options.httpLog.error,
          logPrint: core.options.httpLog.logPrint));
    }
  }

  @override
  Future<HttpResult<T>> request<T>(RequestParams params) async {
    assert(params != null);
    // 先初始化dio对象
    _initDio(params);

    if (params.transformer != null) {
      _dio.transformer = params.transformer;
    }

    // 防止重复添加
    _initInterceptors();
    if (params.interceptors != null && params.interceptors.isNotEmpty) {
      params.interceptors.forEach((element) {
        _dio.interceptors.add(element);
      });
    }

    String url = wrapUrlByParams(params.method, params.url, params.data);
    try {
      Response response = await _doRequest(url, params);
      T data = params.parser<T>(response.data);
      return HttpResult<T>(ResultStatus.success, data: data);
    } catch (e) {
      return HttpResult<T>(ResultStatus.failed, error: e);
    }
  }

  Future<Response> _doRequest(String url, RequestParams params) async {
    Future<Response> response;
    switch (params.method) {
      case HttpMethod.POST:
        response = _dio.post(url, data: params.data);
        break;
      case HttpMethod.PUT:
        response = _dio.put(url, data: params.data);
        break;
      case HttpMethod.DELETE:
        response = _dio.delete(url, data: params.data);
        break;
      case HttpMethod.HEAD:
        response = _dio.head(url);
        break;
      case HttpMethod.PATCH:
        response = _dio.patch(url);
        break;
      case HttpMethod.GET:
      default:
        response = _dio.get(url);
        break;
    }
    return response;
  }

  _initDio(RequestParams params) {
    if (_dio != null) {
      return;
    }
    _dio = Dio(BaseOptions(
        baseUrl: _baseApiUrl,
        connectTimeout: params.timeout,
        receiveTimeout: params.timeout,
        headers: params.header ?? _defaultHeaders,
        contentType: params.contentType ?? Headers.jsonContentType,
        responseType: params.responseType ?? ResponseType.json,
        validateStatus: (status) {
          return status >= 200 && status < 300 || status == 304;
        }));
  }
}
